@@ -10,24 +10,31 @@ from .job import create_job, load_job, run_job
 from .job import job as register_job
 from .task import Task
 from .taskset import load_taskset
-from .telemetry import flush, init_telemetry, trace
+from .telemetry import flush, trace, trace_open
 from .version import __version__
 
-if settings.settings.telemetry_enabled:
-    init_telemetry()
+
+def init_telemetry() -> None:
+    from .telemetry import init_telemetry as _init_telemetry
+
+    _init_telemetry()
+
 
 if settings.settings.fancy_logging:
     import logging
+    import sys
 
     hud_logger = logging.getLogger("hud")
-    # TODO: Make this configurable
     hud_logger.setLevel(logging.INFO)
 
     if not hud_logger.handlers:
-        handler = logging.StreamHandler()
+        # Use the configured stream (defaults to stderr)
+        stream = sys.stderr if settings.settings.log_stream.lower() == "stderr" else sys.stdout
+        handler = logging.StreamHandler(stream)
         formatter = logging.Formatter("[%(levelname)s] %(asctime)s | %(name)s | %(message)s")
         handler.setFormatter(formatter)
         hud_logger.addHandler(handler)
+        hud_logger.propagate = False
 
 __all__ = [
     "Response",
@@ -38,6 +45,7 @@ __all__ = [
     "env",
     "flush",
     "gym",
+    "init_telemetry",
     "load_job",
     "load_taskset",
     "register_job",
@@ -46,6 +54,7 @@ __all__ = [
     "task",
     "taskset",
     "trace",
+    "trace_open",
     "types",
     "utils",
 ]
